==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/nlt_digest_send.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

// headers
$lang['hdr_rsp_blog'] = 						"Latest blogs";
$lang['hdr_rsp_subject'] = 						"Latest discussions";
$lang['hdr_rsp_library'] = 						"Latest library items";
$lang['hdr_rsp_schedule'] = 					"Latest schedule items";
$lang['hdr_rsp_poll'] = 						"Latest polls";

$lang['hdr_bookmark_blog'] = 					"Your bookmarked blogs";
$lang['hdr_bookmark_subject'] = 				"Your bookmarked discussions";
$lang['hdr_bookmark_library'] = 				"Your bookmarked library items";
$lang['hdr_bookmark_schedule'] = 				"Your bookmarked schedule items";
$lang['hdr_bookmark_poll'] = 					"Your bookmarked polls";

$lang['hdr_pub_blog'] = 						"Your published discussions";
$lang['hdr_pub_subject'] = 						"Your published blogs";
$lang['hdr_pub_library'] = 						"Your published library items";
$lang['hdr_pub_schedule'] = 					"Your published schedule items";
$lang['hdr_pub_poll'] = 						"Your published polls";

$lang['hdr_group'] = 							"Your groups";
$lang['hdr_statistics'] = 						"Your statistics";
$lang['hdr_network'] = 							"Your network";

//section titles
$lang['txt_subject'] = 							"AROUNDMe weekly digest";


// texts
$lang['txt_greeting'] = 						"Hi"; // Hi tom
$lang['txt_intro'] = 							"This weeks newsletter from your AROUNDMe instance. The number of comments received in the last seven days are displayed brackets."; // Hi tom
$lang['txt_outro'] = 							"You have received this weekly digest because you have requested it in your account. You can stop this by logging in, going to 'me' and unchecking the digest newsletter box.";

?>

==> aroundme_0_6_3.zip: aroundme_0_6_3/aroundme/language/1/barnraiser_01/nlt_digest_send.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//section titles
$lang['hdr_sent'] = 						"sent";
// headers
$lang['hdr_rsp_blog'] = 						"Latest blogs";
$lang['hdr_rsp_subject'] = 						"Latest discussions";
$lang['hdr_rsp_library'] = 						"Latest library items";
$lang['hdr_rsp_schedule'] = 					"Latest schedule items";
$lang['hdr_rsp_poll'] = 						"Latest polls";

$lang['hdr_bookmark_blog'] = 					"Your bookmarked blogs";
$lang['hdr_bookmark_subject'] = 				"Your bookmarked discussions";
$lang['hdr_bookmark_library'] = 				"Your bookmarked library items";
$lang['hdr_bookmark_schedule'] = 				"Your bookmarked schedule items";
$lang['hdr_bookmark_poll'] = 					"Your bookmarked polls";

$lang['hdr_pub_blog'] = 						"Your published discussions";
$lang['hdr_pub_subject'] = 						"Your published blogs";
$lang['hdr_pub_library'] = 						"Your published library items";
$lang['hdr_pub_schedule'] = 					"Your published schedule items";
$lang['hdr_pub_poll'] = 						"Your published polls";

$lang['hdr_group'] = 							"Your groups";
$lang['hdr_statistics'] = 						"Your statistics";
$lang['hdr_network'] = 							"Your network";

//section titles
$lang['txt_subject'] = 							"AROUNDMe weekly digest";


// texts
$lang['txt_greeting'] = 						"Hi"; // Hi tom
$lang['txt_intro'] = 							"This weeks newsletter from your AROUNDMe instance. The number of comments received in the last seven days are displayed brackets."; // Hi tom
$lang['txt_outro'] = 							"You have received this weekly digest because you have requested it in your account. You can stop this by logging in, going to 'me' and unchecking the digest newsletter box.";

?>
